# -*- coding: utf-8 -*-
from distutils.core import setup

setup(
    version='0.1.0',
    name='ProxyAnonymityDetector',
    description='detect proxy anonymity with headers information',
    packages=['ProxyAnonymityDetector'],
    url='https://github.com/ezirmusitua/proxy-anonymity-detector',
    download_url='https://github.com/ezirmusitua/proxy-anonymity-detector/releases',
    author='jferroal',
    author_email='jferroal@gmail.com',
    keywords=['proxy', 'request', 'http', 'anonymity'],
    license='MIT'
)
